@@ -18,4 +18,10 @@ from .options.RateModelOptions import RateModelOptions
 from .enum.RateModelTimingType import RateModelTimingType
 from .options.RateModelTimingTypeIsImmediateOptions import RateModelTimingTypeIsImmediateOptions
 from .options.RateModelTimingTypeIsAwaitOptions import RateModelTimingTypeIsAwaitOptions
+from .IncrementalRateModel import IncrementalRateModel
+from .options.IncrementalRateModelOptions import IncrementalRateModelOptions
+from .enum.IncrementalRateModelCalculateType import IncrementalRateModelCalculateType
+from .options.IncrementalRateModelCalculateTypeIsLinearOptions import IncrementalRateModelCalculateTypeIsLinearOptions
+from .options.IncrementalRateModelCalculateTypeIsPowerOptions import IncrementalRateModelCalculateTypeIsPowerOptions
+from .options.IncrementalRateModelCalculateTypeIsGs2ScriptOptions import IncrementalRateModelCalculateTypeIsGs2ScriptOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
