@@ -13,4 +13,9 @@
 # permissions and limitations under the License.
 from .AddExperienceByUserId import AddExperienceByUserId
 from .AddRankCapByUserId import AddRankCapByUserId
-from .SetRankCapByUserId import SetRankCapByUserId
\ No newline at end of file
+from .SetRankCapByUserId import SetRankCapByUserId
+from .MultiplyAcquireActionsByUserId import MultiplyAcquireActionsByUserId
+from .SubExperienceByUserId import SubExperienceByUserId
+from .SubRankCapByUserId import SubRankCapByUserId
+from .VerifyRankByUserId import VerifyRankByUserId
+from .VerifyRankCapByUserId import VerifyRankCapByUserId
\ No newline at end of file
