@@ -17,6 +17,8 @@ from .FormModel import FormModel
 from .options.FormModelOptions import FormModelOptions
 from .MoldModel import MoldModel
 from .options.MoldModelOptions import MoldModelOptions
+from .PropertyFormModel import PropertyFormModel
+from .options.PropertyFormModelOptions import PropertyFormModelOptions
 from .Slot import Slot
 from .options.SlotOptions import SlotOptions
 from .SlotModel import SlotModel
@@ -24,6 +26,4 @@ from .options.SlotModelOptions import SlotModelOptions
 from .SlotWithSignature import SlotWithSignature
 from .options.SlotWithSignatureOptions import SlotWithSignatureOptions
 from .enum.SlotWithSignaturePropertyType import SlotWithSignaturePropertyType
-from .AcquireActionConfig import AcquireActionConfig
-from .options.AcquireActionConfigOptions import AcquireActionConfigOptions
 from .CurrentMasterData import CurrentMasterData
\ No newline at end of file
