@@ -15,7 +15,7 @@ from __future__ import annotations
 from typing import *
 
 from ...core.model import AcquireAction, ConsumeAction
-from ..model.AcquireActionConfig import AcquireActionConfig
+from ...core.model import Config
 
 
 class AcquireActionsToFormProperties(AcquireAction):
@@ -23,16 +23,16 @@ class AcquireActionsToFormProperties(AcquireAction):
     def __init__(
         self,
         namespace_name: str,
-        mold_name: str,
+        mold_model_name: str,
         index: int,
         acquire_action: AcquireAction,
-        config: Optional[List[AcquireActionConfig]] = None,
+        config: Optional[List[Config]] = None,
         user_id: Optional[str] = "#{userId}",
     ):
         properties: Dict[str, Any] = {}
 
         properties["namespaceName"] = namespace_name
-        properties["moldName"] = mold_name
+        properties["moldModelName"] = mold_model_name
         properties["index"] = index
         properties["acquireAction"] = acquire_action
         properties["config"] = config
