@@ -13,4 +13,8 @@
 # permissions and limitations under the License.
 from .NamespaceRef import NamespaceRef
 from .InventoryModelRef import InventoryModelRef
-from .ItemModelRef import ItemModelRef
\ No newline at end of file
+from .ItemModelRef import ItemModelRef
+from .SimpleInventoryModelRef import SimpleInventoryModelRef
+from .SimpleItemModelRef import SimpleItemModelRef
+from .BigInventoryModelRef import BigInventoryModelRef
+from .BigItemModelRef import BigItemModelRef
\ No newline at end of file
